"""
This module exists only to simplify retrieving the version number of chardet
from within setuptools and from chardet subpackages.

:author: Dan Blanchard (dan.blanchard@gmail.com)
"""

__version__ = "6.0.0.post1"
VERSION = __version__.split(".")
